@@ -290,22 +290,35 @@ if __name__ == "__main__":
         w_avg_csize = 20
         eps = 0
         random_norms = True
-        censor_rate = 0.0
-        generated_M = rng.generate_nmf_reconstruction(n_comp=nb_clusters,
-                                                      min_intra_corr=min_corr,
-                                                      max_inter_corr=max_corr,
-                                                      h_avg_clust_size=h_avg_csize,
-                                                      w_avg_clust_size=w_avg_csize,
-                                                      epsilon=eps,
-                                                      random_norms=random_norms)
-        utl.censor_data(mat=generated_M, p=censor_rate, inplace=True)
+        censor_rate = 0.01
+        read_wh_mat = True
         rnstr = "RandNorms" if random_norms else "ConstNorms"
-        wh_name = f"M_nc{nb_clusters}_corrmin{round(min_corr,2)}_" \
-                  f"corrmax{round(max_corr,2)}_noise{round(eps,2)}_{rnstr}_mis{censor_rate}.csv"
-        generated_M.to_csv(res_path / "random_nmf" / wh_name,
-                           float_format="%.4f")
-        df_scree_plot = nmf.generate_scree_plot(generated_M, ncmin=6, ncmax=12)
-        df_scree_plot.to_csv(res_path / f"{wh_name}_screeplot.csv")
+
+        for censor_rate in [0.0, 0.01, 0.05, 0.10]:
+
+            if read_wh_mat:
+                fixed_mat_name = os.getenv("imp_wh_matname")
+                rad_name = fixed_mat_name.split(".csv")[0]
+                wh_name = f"{rad_name}_mis{censor_rate}.csv"
+                # wh_name = "M_nc10_corrmin0.9_corrmax0.1_noise0_RandNorms_mis0.0.csv"
+                generated_M = pd.read_csv(data_path / fixed_mat_name, index_col=0)
+            else:
+                wh_name = f"M_nc{nb_clusters}_corrmin{round(min_corr, 2)}_" \
+                          f"corrmax{round(max_corr, 2)}_noise{round(eps, 2)}_{rnstr}_mis{censor_rate}.csv"
+                generated_M = rng.generate_nmf_reconstruction(n_comp=nb_clusters,
+                                                              min_intra_corr=min_corr,
+                                                              max_inter_corr=max_corr,
+                                                              h_avg_clust_size=h_avg_csize,
+                                                              w_avg_clust_size=w_avg_csize,
+                                                              epsilon=eps,
+                                                              random_norms=random_norms)
+
+            utl.censor_data(mat=generated_M, p=censor_rate, inplace=True)
+
+            generated_M.to_csv(res_path / "random_nmf" / wh_name,
+                               float_format="%.4f")
+            df_scree_plot = nmf.generate_scree_plot(generated_M, ncmin=6, ncmax=30)
+            df_scree_plot.to_csv(res_path / f"{wh_name}_screeplot.csv")
 
     if os.getenv("imp_do_ecodata_gans", "False").lower() == "true":
         # expérience où l'on soumet les résultats de l'imputation à un GAN
